# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Iam Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class AccountcommonGroupAndRoleMappingForUpdate(Model):
    """Accountcommon group and role mapping for update (accountcommon.GroupAndRoleMappingForUpdate)

    Properties:
        group: (group) REQUIRED str

        role_id: (roleId) REQUIRED str

        assign_namespaces: (assignNamespaces) OPTIONAL List[str]
    """

    # region fields

    group: str  # REQUIRED
    role_id: str  # REQUIRED
    assign_namespaces: List[str]  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_group(self, value: str) -> AccountcommonGroupAndRoleMappingForUpdate:
        self.group = value
        return self

    def with_role_id(self, value: str) -> AccountcommonGroupAndRoleMappingForUpdate:
        self.role_id = value
        return self

    def with_assign_namespaces(
        self, value: List[str]
    ) -> AccountcommonGroupAndRoleMappingForUpdate:
        self.assign_namespaces = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "group"):
            result["group"] = str(self.group)
        elif include_empty:
            result["group"] = ""
        if hasattr(self, "role_id"):
            result["roleId"] = str(self.role_id)
        elif include_empty:
            result["roleId"] = ""
        if hasattr(self, "assign_namespaces"):
            result["assignNamespaces"] = [str(i0) for i0 in self.assign_namespaces]
        elif include_empty:
            result["assignNamespaces"] = []
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        group: str,
        role_id: str,
        assign_namespaces: Optional[List[str]] = None,
        **kwargs,
    ) -> AccountcommonGroupAndRoleMappingForUpdate:
        instance = cls()
        instance.group = group
        instance.role_id = role_id
        if assign_namespaces is not None:
            instance.assign_namespaces = assign_namespaces
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> AccountcommonGroupAndRoleMappingForUpdate:
        instance = cls()
        if not dict_:
            return instance
        if "group" in dict_ and dict_["group"] is not None:
            instance.group = str(dict_["group"])
        elif include_empty:
            instance.group = ""
        if "roleId" in dict_ and dict_["roleId"] is not None:
            instance.role_id = str(dict_["roleId"])
        elif include_empty:
            instance.role_id = ""
        if "assignNamespaces" in dict_ and dict_["assignNamespaces"] is not None:
            instance.assign_namespaces = [str(i0) for i0 in dict_["assignNamespaces"]]
        elif include_empty:
            instance.assign_namespaces = []
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, AccountcommonGroupAndRoleMappingForUpdate]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[AccountcommonGroupAndRoleMappingForUpdate]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        AccountcommonGroupAndRoleMappingForUpdate,
        List[AccountcommonGroupAndRoleMappingForUpdate],
        Dict[Any, AccountcommonGroupAndRoleMappingForUpdate],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "group": "group",
            "roleId": "role_id",
            "assignNamespaces": "assign_namespaces",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "group": True,
            "roleId": True,
            "assignNamespaces": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Statistics Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class BulkStatCycleOperationResult(Model):
    """Bulk stat cycle operation result (BulkStatCycleOperationResult)

    Properties:
        cycle_id: (cycleId) OPTIONAL str

        details: (details) OPTIONAL Dict[str, Any]

        stat_code: (statCode) OPTIONAL str

        success: (success) OPTIONAL bool
    """

    # region fields

    cycle_id: str  # OPTIONAL
    details: Dict[str, Any]  # OPTIONAL
    stat_code: str  # OPTIONAL
    success: bool  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_cycle_id(self, value: str) -> BulkStatCycleOperationResult:
        self.cycle_id = value
        return self

    def with_details(self, value: Dict[str, Any]) -> BulkStatCycleOperationResult:
        self.details = value
        return self

    def with_stat_code(self, value: str) -> BulkStatCycleOperationResult:
        self.stat_code = value
        return self

    def with_success(self, value: bool) -> BulkStatCycleOperationResult:
        self.success = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "cycle_id"):
            result["cycleId"] = str(self.cycle_id)
        elif include_empty:
            result["cycleId"] = ""
        if hasattr(self, "details"):
            result["details"] = {str(k0): v0 for k0, v0 in self.details.items()}
        elif include_empty:
            result["details"] = {}
        if hasattr(self, "stat_code"):
            result["statCode"] = str(self.stat_code)
        elif include_empty:
            result["statCode"] = ""
        if hasattr(self, "success"):
            result["success"] = bool(self.success)
        elif include_empty:
            result["success"] = False
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        cycle_id: Optional[str] = None,
        details: Optional[Dict[str, Any]] = None,
        stat_code: Optional[str] = None,
        success: Optional[bool] = None,
        **kwargs,
    ) -> BulkStatCycleOperationResult:
        instance = cls()
        if cycle_id is not None:
            instance.cycle_id = cycle_id
        if details is not None:
            instance.details = details
        if stat_code is not None:
            instance.stat_code = stat_code
        if success is not None:
            instance.success = success
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> BulkStatCycleOperationResult:
        instance = cls()
        if not dict_:
            return instance
        if "cycleId" in dict_ and dict_["cycleId"] is not None:
            instance.cycle_id = str(dict_["cycleId"])
        elif include_empty:
            instance.cycle_id = ""
        if "details" in dict_ and dict_["details"] is not None:
            instance.details = {str(k0): v0 for k0, v0 in dict_["details"].items()}
        elif include_empty:
            instance.details = {}
        if "statCode" in dict_ and dict_["statCode"] is not None:
            instance.stat_code = str(dict_["statCode"])
        elif include_empty:
            instance.stat_code = ""
        if "success" in dict_ and dict_["success"] is not None:
            instance.success = bool(dict_["success"])
        elif include_empty:
            instance.success = False
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, BulkStatCycleOperationResult]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[BulkStatCycleOperationResult]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        BulkStatCycleOperationResult,
        List[BulkStatCycleOperationResult],
        Dict[Any, BulkStatCycleOperationResult],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "cycleId": "cycle_id",
            "details": "details",
            "statCode": "stat_code",
            "success": "success",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "cycleId": False,
            "details": False,
            "statCode": False,
            "success": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Session Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class ModelsXBLCertificateCredential(Model):
    """Models XBL certificate credential (models.XBLCertificateCredential)

    Properties:
        business_partner_cert_file_bytes: (businessPartnerCertFileBytes) REQUIRED str

        business_partner_cert_file_name: (businessPartnerCertFileName) REQUIRED str

        created_at: (createdAt) REQUIRED str

        created_by: (createdBy) REQUIRED str

        namespace: (namespace) REQUIRED str

        updated_at: (updatedAt) REQUIRED str

        description: (description) OPTIONAL str
    """

    # region fields

    business_partner_cert_file_bytes: str  # REQUIRED
    business_partner_cert_file_name: str  # REQUIRED
    created_at: str  # REQUIRED
    created_by: str  # REQUIRED
    namespace: str  # REQUIRED
    updated_at: str  # REQUIRED
    description: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_business_partner_cert_file_bytes(
        self, value: str
    ) -> ModelsXBLCertificateCredential:
        self.business_partner_cert_file_bytes = value
        return self

    def with_business_partner_cert_file_name(
        self, value: str
    ) -> ModelsXBLCertificateCredential:
        self.business_partner_cert_file_name = value
        return self

    def with_created_at(self, value: str) -> ModelsXBLCertificateCredential:
        self.created_at = value
        return self

    def with_created_by(self, value: str) -> ModelsXBLCertificateCredential:
        self.created_by = value
        return self

    def with_namespace(self, value: str) -> ModelsXBLCertificateCredential:
        self.namespace = value
        return self

    def with_updated_at(self, value: str) -> ModelsXBLCertificateCredential:
        self.updated_at = value
        return self

    def with_description(self, value: str) -> ModelsXBLCertificateCredential:
        self.description = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "business_partner_cert_file_bytes"):
            result["businessPartnerCertFileBytes"] = str(
                self.business_partner_cert_file_bytes
            )
        elif include_empty:
            result["businessPartnerCertFileBytes"] = ""
        if hasattr(self, "business_partner_cert_file_name"):
            result["businessPartnerCertFileName"] = str(
                self.business_partner_cert_file_name
            )
        elif include_empty:
            result["businessPartnerCertFileName"] = ""
        if hasattr(self, "created_at"):
            result["createdAt"] = str(self.created_at)
        elif include_empty:
            result["createdAt"] = ""
        if hasattr(self, "created_by"):
            result["createdBy"] = str(self.created_by)
        elif include_empty:
            result["createdBy"] = ""
        if hasattr(self, "namespace"):
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "updated_at"):
            result["updatedAt"] = str(self.updated_at)
        elif include_empty:
            result["updatedAt"] = ""
        if hasattr(self, "description"):
            result["description"] = str(self.description)
        elif include_empty:
            result["description"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        business_partner_cert_file_bytes: str,
        business_partner_cert_file_name: str,
        created_at: str,
        created_by: str,
        namespace: str,
        updated_at: str,
        description: Optional[str] = None,
        **kwargs,
    ) -> ModelsXBLCertificateCredential:
        instance = cls()
        instance.business_partner_cert_file_bytes = business_partner_cert_file_bytes
        instance.business_partner_cert_file_name = business_partner_cert_file_name
        instance.created_at = created_at
        instance.created_by = created_by
        instance.namespace = namespace
        instance.updated_at = updated_at
        if description is not None:
            instance.description = description
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsXBLCertificateCredential:
        instance = cls()
        if not dict_:
            return instance
        if (
            "businessPartnerCertFileBytes" in dict_
            and dict_["businessPartnerCertFileBytes"] is not None
        ):
            instance.business_partner_cert_file_bytes = str(
                dict_["businessPartnerCertFileBytes"]
            )
        elif include_empty:
            instance.business_partner_cert_file_bytes = ""
        if (
            "businessPartnerCertFileName" in dict_
            and dict_["businessPartnerCertFileName"] is not None
        ):
            instance.business_partner_cert_file_name = str(
                dict_["businessPartnerCertFileName"]
            )
        elif include_empty:
            instance.business_partner_cert_file_name = ""
        if "createdAt" in dict_ and dict_["createdAt"] is not None:
            instance.created_at = str(dict_["createdAt"])
        elif include_empty:
            instance.created_at = ""
        if "createdBy" in dict_ and dict_["createdBy"] is not None:
            instance.created_by = str(dict_["createdBy"])
        elif include_empty:
            instance.created_by = ""
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "updatedAt" in dict_ and dict_["updatedAt"] is not None:
            instance.updated_at = str(dict_["updatedAt"])
        elif include_empty:
            instance.updated_at = ""
        if "description" in dict_ and dict_["description"] is not None:
            instance.description = str(dict_["description"])
        elif include_empty:
            instance.description = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsXBLCertificateCredential]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsXBLCertificateCredential]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsXBLCertificateCredential,
        List[ModelsXBLCertificateCredential],
        Dict[Any, ModelsXBLCertificateCredential],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "businessPartnerCertFileBytes": "business_partner_cert_file_bytes",
            "businessPartnerCertFileName": "business_partner_cert_file_name",
            "createdAt": "created_at",
            "createdBy": "created_by",
            "namespace": "namespace",
            "updatedAt": "updated_at",
            "description": "description",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "businessPartnerCertFileBytes": True,
            "businessPartnerCertFileName": True,
            "createdAt": True,
            "createdBy": True,
            "namespace": True,
            "updatedAt": True,
            "description": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

# Fleet Commander

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from .....core import Operation
from .....core import HeaderStr
from .....core import HttpResponse

from ...models import ApiImageList
from ...models import ResponseErrorResponse


class ImageList(Operation):
    """get a list of existing images (ImageList)

    Returns images which exist (uploaded, uploading, or building) in the linked account. This route fails if no account is linked

    Required Permission: ADMIN:NAMESPACE:{namespace}:AMS:IMAGE [READ]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/images

        method: GET

        tags: ["Images"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        count: (count) OPTIONAL int in query

        in_use: (inUse) OPTIONAL str in query

        is_protected: (isProtected) OPTIONAL bool in query

        name: (name) OPTIONAL str in query

        offset: (offset) OPTIONAL int in query

        sort_by: (sortBy) OPTIONAL str in query

        sort_direction: (sortDirection) OPTIONAL str in query

        status: (status) OPTIONAL str in query

        tag: (tag) OPTIONAL str in query

        target_architecture: (targetArchitecture) OPTIONAL str in query

    Responses:
        200: OK - ApiImageList (success)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        404: Not Found - ResponseErrorResponse (account not linked)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """

    # region fields

    _url: str = "/ams/v1/admin/namespaces/{namespace}/images"
    _method: str = "GET"
    _consumes: List[str] = ["application/json"]
    _produces: List[str] = ["application/json"]
    _securities: List[List[str]] = [["BEARER_AUTH"]]
    _location_query: str = None

    namespace: str  # REQUIRED in [path]
    count: int  # OPTIONAL in [query]
    in_use: str  # OPTIONAL in [query]
    is_protected: bool  # OPTIONAL in [query]
    name: str  # OPTIONAL in [query]
    offset: int  # OPTIONAL in [query]
    sort_by: str  # OPTIONAL in [query]
    sort_direction: str  # OPTIONAL in [query]
    status: str  # OPTIONAL in [query]
    tag: str  # OPTIONAL in [query]
    target_architecture: str  # OPTIONAL in [query]

    # endregion fields

    # region properties

    @property
    def url(self) -> str:
        return self._url

    @property
    def method(self) -> str:
        return self._method

    @property
    def consumes(self) -> List[str]:
        return self._consumes

    @property
    def produces(self) -> List[str]:
        return self._produces

    @property
    def securities(self) -> List[List[str]]:
        return self._securities

    @property
    def location_query(self) -> str:
        return self._location_query

    # endregion properties

    # region get methods

    # endregion get methods

    # region get_x_params methods

    def get_all_params(self) -> dict:
        return {
            "path": self.get_path_params(),
            "query": self.get_query_params(),
        }

    def get_path_params(self) -> dict:
        result = {}
        if hasattr(self, "namespace"):
            result["namespace"] = self.namespace
        return result

    def get_query_params(self) -> dict:
        result = {}
        if hasattr(self, "count"):
            result["count"] = self.count
        if hasattr(self, "in_use"):
            result["inUse"] = self.in_use
        if hasattr(self, "is_protected"):
            result["isProtected"] = self.is_protected
        if hasattr(self, "name"):
            result["name"] = self.name
        if hasattr(self, "offset"):
            result["offset"] = self.offset
        if hasattr(self, "sort_by"):
            result["sortBy"] = self.sort_by
        if hasattr(self, "sort_direction"):
            result["sortDirection"] = self.sort_direction
        if hasattr(self, "status"):
            result["status"] = self.status
        if hasattr(self, "tag"):
            result["tag"] = self.tag
        if hasattr(self, "target_architecture"):
            result["targetArchitecture"] = self.target_architecture
        return result

    # endregion get_x_params methods

    # region is/has methods

    # endregion is/has methods

    # region with_x methods

    def with_namespace(self, value: str) -> ImageList:
        self.namespace = value
        return self

    def with_count(self, value: int) -> ImageList:
        self.count = value
        return self

    def with_in_use(self, value: str) -> ImageList:
        self.in_use = value
        return self

    def with_is_protected(self, value: bool) -> ImageList:
        self.is_protected = value
        return self

    def with_name(self, value: str) -> ImageList:
        self.name = value
        return self

    def with_offset(self, value: int) -> ImageList:
        self.offset = value
        return self

    def with_sort_by(self, value: str) -> ImageList:
        self.sort_by = value
        return self

    def with_sort_direction(self, value: str) -> ImageList:
        self.sort_direction = value
        return self

    def with_status(self, value: str) -> ImageList:
        self.status = value
        return self

    def with_tag(self, value: str) -> ImageList:
        self.tag = value
        return self

    def with_target_architecture(self, value: str) -> ImageList:
        self.target_architecture = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "namespace") and self.namespace:
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "count") and self.count:
            result["count"] = int(self.count)
        elif include_empty:
            result["count"] = 0
        if hasattr(self, "in_use") and self.in_use:
            result["inUse"] = str(self.in_use)
        elif include_empty:
            result["inUse"] = ""
        if hasattr(self, "is_protected") and self.is_protected:
            result["isProtected"] = bool(self.is_protected)
        elif include_empty:
            result["isProtected"] = False
        if hasattr(self, "name") and self.name:
            result["name"] = str(self.name)
        elif include_empty:
            result["name"] = ""
        if hasattr(self, "offset") and self.offset:
            result["offset"] = int(self.offset)
        elif include_empty:
            result["offset"] = 0
        if hasattr(self, "sort_by") and self.sort_by:
            result["sortBy"] = str(self.sort_by)
        elif include_empty:
            result["sortBy"] = ""
        if hasattr(self, "sort_direction") and self.sort_direction:
            result["sortDirection"] = str(self.sort_direction)
        elif include_empty:
            result["sortDirection"] = ""
        if hasattr(self, "status") and self.status:
            result["status"] = str(self.status)
        elif include_empty:
            result["status"] = ""
        if hasattr(self, "tag") and self.tag:
            result["tag"] = str(self.tag)
        elif include_empty:
            result["tag"] = ""
        if hasattr(self, "target_architecture") and self.target_architecture:
            result["targetArchitecture"] = str(self.target_architecture)
        elif include_empty:
            result["targetArchitecture"] = ""
        return result

    # endregion to methods

    # region response methods

    # noinspection PyMethodMayBeStatic
    def parse_response(
        self, code: int, content_type: str, content: Any
    ) -> Tuple[
        Union[None, ApiImageList], Union[None, HttpResponse, ResponseErrorResponse]
    ]:
        """Parse the given response.

        200: OK - ApiImageList (success)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        404: Not Found - ResponseErrorResponse (account not linked)

        500: Internal Server Error - ResponseErrorResponse (internal server error)

        ---: HttpResponse (Undocumented Response)

        ---: HttpResponse (Unexpected Content-Type Error)

        ---: HttpResponse (Unhandled Error)
        """
        pre_processed_response, error = self.pre_process_response(
            code=code, content_type=content_type, content=content
        )
        if error is not None:
            return None, None if error.is_no_content() else error
        code, content_type, content = pre_processed_response

        if code == 200:
            return ApiImageList.create_from_dict(content), None
        if code == 401:
            return None, ResponseErrorResponse.create_from_dict(content)
        if code == 403:
            return None, ResponseErrorResponse.create_from_dict(content)
        if code == 404:
            return None, ResponseErrorResponse.create_from_dict(content)
        if code == 500:
            return None, ResponseErrorResponse.create_from_dict(content)

        return self.handle_undocumented_response(
            code=code, content_type=content_type, content=content
        )

    # endregion response methods

    # region static methods

    @classmethod
    def create(
        cls,
        namespace: str,
        count: Optional[int] = None,
        in_use: Optional[str] = None,
        is_protected: Optional[bool] = None,
        name: Optional[str] = None,
        offset: Optional[int] = None,
        sort_by: Optional[str] = None,
        sort_direction: Optional[str] = None,
        status: Optional[str] = None,
        tag: Optional[str] = None,
        target_architecture: Optional[str] = None,
        **kwargs,
    ) -> ImageList:
        instance = cls()
        instance.namespace = namespace
        if count is not None:
            instance.count = count
        if in_use is not None:
            instance.in_use = in_use
        if is_protected is not None:
            instance.is_protected = is_protected
        if name is not None:
            instance.name = name
        if offset is not None:
            instance.offset = offset
        if sort_by is not None:
            instance.sort_by = sort_by
        if sort_direction is not None:
            instance.sort_direction = sort_direction
        if status is not None:
            instance.status = status
        if tag is not None:
            instance.tag = tag
        if target_architecture is not None:
            instance.target_architecture = target_architecture
        if x_flight_id := kwargs.get("x_flight_id", None):
            instance.x_flight_id = x_flight_id
        return instance

    @classmethod
    def create_from_dict(cls, dict_: dict, include_empty: bool = False) -> ImageList:
        instance = cls()
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "count" in dict_ and dict_["count"] is not None:
            instance.count = int(dict_["count"])
        elif include_empty:
            instance.count = 0
        if "inUse" in dict_ and dict_["inUse"] is not None:
            instance.in_use = str(dict_["inUse"])
        elif include_empty:
            instance.in_use = ""
        if "isProtected" in dict_ and dict_["isProtected"] is not None:
            instance.is_protected = bool(dict_["isProtected"])
        elif include_empty:
            instance.is_protected = False
        if "name" in dict_ and dict_["name"] is not None:
            instance.name = str(dict_["name"])
        elif include_empty:
            instance.name = ""
        if "offset" in dict_ and dict_["offset"] is not None:
            instance.offset = int(dict_["offset"])
        elif include_empty:
            instance.offset = 0
        if "sortBy" in dict_ and dict_["sortBy"] is not None:
            instance.sort_by = str(dict_["sortBy"])
        elif include_empty:
            instance.sort_by = ""
        if "sortDirection" in dict_ and dict_["sortDirection"] is not None:
            instance.sort_direction = str(dict_["sortDirection"])
        elif include_empty:
            instance.sort_direction = ""
        if "status" in dict_ and dict_["status"] is not None:
            instance.status = str(dict_["status"])
        elif include_empty:
            instance.status = ""
        if "tag" in dict_ and dict_["tag"] is not None:
            instance.tag = str(dict_["tag"])
        elif include_empty:
            instance.tag = ""
        if "targetArchitecture" in dict_ and dict_["targetArchitecture"] is not None:
            instance.target_architecture = str(dict_["targetArchitecture"])
        elif include_empty:
            instance.target_architecture = ""
        return instance

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "namespace": "namespace",
            "count": "count",
            "inUse": "in_use",
            "isProtected": "is_protected",
            "name": "name",
            "offset": "offset",
            "sortBy": "sort_by",
            "sortDirection": "sort_direction",
            "status": "status",
            "tag": "tag",
            "targetArchitecture": "target_architecture",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "namespace": True,
            "count": False,
            "inUse": False,
            "isProtected": False,
            "name": False,
            "offset": False,
            "sortBy": False,
            "sortDirection": False,
            "status": False,
            "tag": False,
            "targetArchitecture": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Platform Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class ThirdPartySubscriptionTierInfo(Model):
    """Third party subscription tier info (ThirdPartySubscriptionTierInfo)

    Properties:
        group_sku: (groupSku) OPTIONAL str

        sku: (sku) OPTIONAL str
    """

    # region fields

    group_sku: str  # OPTIONAL
    sku: str  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_group_sku(self, value: str) -> ThirdPartySubscriptionTierInfo:
        self.group_sku = value
        return self

    def with_sku(self, value: str) -> ThirdPartySubscriptionTierInfo:
        self.sku = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "group_sku"):
            result["groupSku"] = str(self.group_sku)
        elif include_empty:
            result["groupSku"] = ""
        if hasattr(self, "sku"):
            result["sku"] = str(self.sku)
        elif include_empty:
            result["sku"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls, group_sku: Optional[str] = None, sku: Optional[str] = None, **kwargs
    ) -> ThirdPartySubscriptionTierInfo:
        instance = cls()
        if group_sku is not None:
            instance.group_sku = group_sku
        if sku is not None:
            instance.sku = sku
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ThirdPartySubscriptionTierInfo:
        instance = cls()
        if not dict_:
            return instance
        if "groupSku" in dict_ and dict_["groupSku"] is not None:
            instance.group_sku = str(dict_["groupSku"])
        elif include_empty:
            instance.group_sku = ""
        if "sku" in dict_ and dict_["sku"] is not None:
            instance.sku = str(dict_["sku"])
        elif include_empty:
            instance.sku = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ThirdPartySubscriptionTierInfo]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ThirdPartySubscriptionTierInfo]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ThirdPartySubscriptionTierInfo,
        List[ThirdPartySubscriptionTierInfo],
        Dict[Any, ThirdPartySubscriptionTierInfo],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "groupSku": "group_sku",
            "sku": "sku",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "groupSku": False,
            "sku": False,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Legal Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model
from ....core import StrEnum


class CountryTypeEnum(StrEnum):
    COUNTRY = "COUNTRY"
    COUNTRY_GROUP = "COUNTRY_GROUP"


class CreatePolicyRequest(Model):
    """Create policy request (CreatePolicyRequest)

    Properties:
        countries: (countries) OPTIONAL List[str]

        country_code: (countryCode) OPTIONAL str

        country_group_name: (countryGroupName) OPTIONAL str

        country_type: (countryType) OPTIONAL Union[str, CountryTypeEnum]

        description: (description) OPTIONAL str

        is_default_selection: (isDefaultSelection) OPTIONAL bool

        is_mandatory: (isMandatory) OPTIONAL bool

        policy_name: (policyName) OPTIONAL str

        should_notify_on_update: (shouldNotifyOnUpdate) OPTIONAL bool
    """

    # region fields

    countries: List[str]  # OPTIONAL
    country_code: str  # OPTIONAL
    country_group_name: str  # OPTIONAL
    country_type: Union[str, CountryTypeEnum]  # OPTIONAL
    description: str  # OPTIONAL
    is_default_selection: bool  # OPTIONAL
    is_mandatory: bool  # OPTIONAL
    policy_name: str  # OPTIONAL
    should_notify_on_update: bool  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_countries(self, value: List[str]) -> CreatePolicyRequest:
        self.countries = value
        return self

    def with_country_code(self, value: str) -> CreatePolicyRequest:
        self.country_code = value
        return self

    def with_country_group_name(self, value: str) -> CreatePolicyRequest:
        self.country_group_name = value
        return self

    def with_country_type(
        self, value: Union[str, CountryTypeEnum]
    ) -> CreatePolicyRequest:
        self.country_type = value
        return self

    def with_description(self, value: str) -> CreatePolicyRequest:
        self.description = value
        return self

    def with_is_default_selection(self, value: bool) -> CreatePolicyRequest:
        self.is_default_selection = value
        return self

    def with_is_mandatory(self, value: bool) -> CreatePolicyRequest:
        self.is_mandatory = value
        return self

    def with_policy_name(self, value: str) -> CreatePolicyRequest:
        self.policy_name = value
        return self

    def with_should_notify_on_update(self, value: bool) -> CreatePolicyRequest:
        self.should_notify_on_update = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "countries"):
            result["countries"] = [str(i0) for i0 in self.countries]
        elif include_empty:
            result["countries"] = []
        if hasattr(self, "country_code"):
            result["countryCode"] = str(self.country_code)
        elif include_empty:
            result["countryCode"] = ""
        if hasattr(self, "country_group_name"):
            result["countryGroupName"] = str(self.country_group_name)
        elif include_empty:
            result["countryGroupName"] = ""
        if hasattr(self, "country_type"):
            result["countryType"] = str(self.country_type)
        elif include_empty:
            result["countryType"] = Union[str, CountryTypeEnum]()
        if hasattr(self, "description"):
            result["description"] = str(self.description)
        elif include_empty:
            result["description"] = ""
        if hasattr(self, "is_default_selection"):
            result["isDefaultSelection"] = bool(self.is_default_selection)
        elif include_empty:
            result["isDefaultSelection"] = False
        if hasattr(self, "is_mandatory"):
            result["isMandatory"] = bool(self.is_mandatory)
        elif include_empty:
            result["isMandatory"] = False
        if hasattr(self, "policy_name"):
            result["policyName"] = str(self.policy_name)
        elif include_empty:
            result["policyName"] = ""
        if hasattr(self, "should_notify_on_update"):
            result["shouldNotifyOnUpdate"] = bool(self.should_notify_on_update)
        elif include_empty:
            result["shouldNotifyOnUpdate"] = False
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        countries: Optional[List[str]] = None,
        country_code: Optional[str] = None,
        country_group_name: Optional[str] = None,
        country_type: Optional[Union[str, CountryTypeEnum]] = None,
        description: Optional[str] = None,
        is_default_selection: Optional[bool] = None,
        is_mandatory: Optional[bool] = None,
        policy_name: Optional[str] = None,
        should_notify_on_update: Optional[bool] = None,
        **kwargs,
    ) -> CreatePolicyRequest:
        instance = cls()
        if countries is not None:
            instance.countries = countries
        if country_code is not None:
            instance.country_code = country_code
        if country_group_name is not None:
            instance.country_group_name = country_group_name
        if country_type is not None:
            instance.country_type = country_type
        if description is not None:
            instance.description = description
        if is_default_selection is not None:
            instance.is_default_selection = is_default_selection
        if is_mandatory is not None:
            instance.is_mandatory = is_mandatory
        if policy_name is not None:
            instance.policy_name = policy_name
        if should_notify_on_update is not None:
            instance.should_notify_on_update = should_notify_on_update
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> CreatePolicyRequest:
        instance = cls()
        if not dict_:
            return instance
        if "countries" in dict_ and dict_["countries"] is not None:
            instance.countries = [str(i0) for i0 in dict_["countries"]]
        elif include_empty:
            instance.countries = []
        if "countryCode" in dict_ and dict_["countryCode"] is not None:
            instance.country_code = str(dict_["countryCode"])
        elif include_empty:
            instance.country_code = ""
        if "countryGroupName" in dict_ and dict_["countryGroupName"] is not None:
            instance.country_group_name = str(dict_["countryGroupName"])
        elif include_empty:
            instance.country_group_name = ""
        if "countryType" in dict_ and dict_["countryType"] is not None:
            instance.country_type = str(dict_["countryType"])
        elif include_empty:
            instance.country_type = Union[str, CountryTypeEnum]()
        if "description" in dict_ and dict_["description"] is not None:
            instance.description = str(dict_["description"])
        elif include_empty:
            instance.description = ""
        if "isDefaultSelection" in dict_ and dict_["isDefaultSelection"] is not None:
            instance.is_default_selection = bool(dict_["isDefaultSelection"])
        elif include_empty:
            instance.is_default_selection = False
        if "isMandatory" in dict_ and dict_["isMandatory"] is not None:
            instance.is_mandatory = bool(dict_["isMandatory"])
        elif include_empty:
            instance.is_mandatory = False
        if "policyName" in dict_ and dict_["policyName"] is not None:
            instance.policy_name = str(dict_["policyName"])
        elif include_empty:
            instance.policy_name = ""
        if (
            "shouldNotifyOnUpdate" in dict_
            and dict_["shouldNotifyOnUpdate"] is not None
        ):
            instance.should_notify_on_update = bool(dict_["shouldNotifyOnUpdate"])
        elif include_empty:
            instance.should_notify_on_update = False
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, CreatePolicyRequest]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[CreatePolicyRequest]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        CreatePolicyRequest, List[CreatePolicyRequest], Dict[Any, CreatePolicyRequest]
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "countries": "countries",
            "countryCode": "country_code",
            "countryGroupName": "country_group_name",
            "countryType": "country_type",
            "description": "description",
            "isDefaultSelection": "is_default_selection",
            "isMandatory": "is_mandatory",
            "policyName": "policy_name",
            "shouldNotifyOnUpdate": "should_notify_on_update",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "countries": False,
            "countryCode": False,
            "countryGroupName": False,
            "countryType": False,
            "description": False,
            "isDefaultSelection": False,
            "isMandatory": False,
            "policyName": False,
            "shouldNotifyOnUpdate": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "countryType": ["COUNTRY", "COUNTRY_GROUP"],
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Iam Service."""

__version__ = "7.37.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_get_profile_updat_5f84fb import AdminGetProfileUpdateStrategyV3
from .admin_get_profile_updat_5f84fb import (
    FieldEnum as AdminGetProfileUpdateStrategyV3FieldEnum,
)
from .admin_update_profile_up_038023 import AdminUpdateProfileUpdateStrategyV3
from .admin_update_profile_up_038023 import (
    FieldEnum as AdminUpdateProfileUpdateStrategyV3FieldEnum,
)
from .public_get_profile_upda_626804 import PublicGetProfileUpdateStrategyV3
from .public_get_profile_upda_626804 import (
    FieldEnum as PublicGetProfileUpdateStrategyV3FieldEnum,
)



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Cloudsave Service."""

__version__ = "3.30.0"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .admin_put_admin_game_re_99ac43 import AdminPutAdminGameRecordConcurrentHandlerV1
from .admin_put_admin_player__e84e5d import AdminPutAdminPlayerRecordConcurrentHandlerV1
from .admin_put_game_record_c_886b02 import AdminPutGameRecordConcurrentHandlerV1
from .admin_put_player_public_1624a9 import (
    AdminPutPlayerPublicRecordConcurrentHandlerV1,
)
from .admin_put_player_record_233704 import AdminPutPlayerRecordConcurrentHandlerV1



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Cloudsave Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class ModelsBulkUpdatePlayerRecordResponse(Model):
    """Models bulk update player record response (models.BulkUpdatePlayerRecordResponse)

    Properties:
        detail: (detail) REQUIRED Dict[str, Any]

        key: (key) REQUIRED str

        success: (success) REQUIRED bool
    """

    # region fields

    detail: Dict[str, Any]  # REQUIRED
    key: str  # REQUIRED
    success: bool  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_detail(
        self, value: Dict[str, Any]
    ) -> ModelsBulkUpdatePlayerRecordResponse:
        self.detail = value
        return self

    def with_key(self, value: str) -> ModelsBulkUpdatePlayerRecordResponse:
        self.key = value
        return self

    def with_success(self, value: bool) -> ModelsBulkUpdatePlayerRecordResponse:
        self.success = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "detail"):
            result["detail"] = {str(k0): v0 for k0, v0 in self.detail.items()}
        elif include_empty:
            result["detail"] = {}
        if hasattr(self, "key"):
            result["key"] = str(self.key)
        elif include_empty:
            result["key"] = ""
        if hasattr(self, "success"):
            result["success"] = bool(self.success)
        elif include_empty:
            result["success"] = False
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls, detail: Dict[str, Any], key: str, success: bool, **kwargs
    ) -> ModelsBulkUpdatePlayerRecordResponse:
        instance = cls()
        instance.detail = detail
        instance.key = key
        instance.success = success
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsBulkUpdatePlayerRecordResponse:
        instance = cls()
        if not dict_:
            return instance
        if "detail" in dict_ and dict_["detail"] is not None:
            instance.detail = {str(k0): v0 for k0, v0 in dict_["detail"].items()}
        elif include_empty:
            instance.detail = {}
        if "key" in dict_ and dict_["key"] is not None:
            instance.key = str(dict_["key"])
        elif include_empty:
            instance.key = ""
        if "success" in dict_ and dict_["success"] is not None:
            instance.success = bool(dict_["success"])
        elif include_empty:
            instance.success = False
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsBulkUpdatePlayerRecordResponse]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsBulkUpdatePlayerRecordResponse]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsBulkUpdatePlayerRecordResponse,
        List[ModelsBulkUpdatePlayerRecordResponse],
        Dict[Any, ModelsBulkUpdatePlayerRecordResponse],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "detail": "detail",
            "key": "key",
            "success": "success",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "detail": True,
            "key": True,
            "success": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Legal Service."""

__version__ = "4.6.1"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .download_exported_agree_a56e5b import DownloadExportedAgreementsInCSV
from .initiate_export_agreeme_d92c31 import InitiateExportAgreementsToCSV
from .retrieve_accepted_agreements import RetrieveAcceptedAgreements
from .retrieve_accepted_agree_8c230d import RetrieveAcceptedAgreementsForMultiUsers
from .retrieve_all_users_by_p_90a012 import RetrieveAllUsersByPolicyVersion



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Platform Service

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model
from ....core import StrEnum


class EnvEnum(StrEnum):
    LIVE = "LIVE"
    SANDBOX = "SANDBOX"


class SyncModeEnum(StrEnum):
    INVENTORY = "INVENTORY"
    TRANSACTION = "TRANSACTION"


class SteamIAPConfigRequest(Model):
    """Steam IAP config request (SteamIAPConfigRequest)

    Properties:
        app_id: (appId) REQUIRED str

        env: (env) OPTIONAL Union[str, EnvEnum]

        publisher_authentication_key: (publisherAuthenticationKey) OPTIONAL str

        sync_mode: (syncMode) OPTIONAL Union[str, SyncModeEnum]
    """

    # region fields

    app_id: str  # REQUIRED
    env: Union[str, EnvEnum]  # OPTIONAL
    publisher_authentication_key: str  # OPTIONAL
    sync_mode: Union[str, SyncModeEnum]  # OPTIONAL

    # endregion fields

    # region with_x methods

    def with_app_id(self, value: str) -> SteamIAPConfigRequest:
        self.app_id = value
        return self

    def with_env(self, value: Union[str, EnvEnum]) -> SteamIAPConfigRequest:
        self.env = value
        return self

    def with_publisher_authentication_key(self, value: str) -> SteamIAPConfigRequest:
        self.publisher_authentication_key = value
        return self

    def with_sync_mode(self, value: Union[str, SyncModeEnum]) -> SteamIAPConfigRequest:
        self.sync_mode = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "app_id"):
            result["appId"] = str(self.app_id)
        elif include_empty:
            result["appId"] = ""
        if hasattr(self, "env"):
            result["env"] = str(self.env)
        elif include_empty:
            result["env"] = Union[str, EnvEnum]()
        if hasattr(self, "publisher_authentication_key"):
            result["publisherAuthenticationKey"] = str(
                self.publisher_authentication_key
            )
        elif include_empty:
            result["publisherAuthenticationKey"] = ""
        if hasattr(self, "sync_mode"):
            result["syncMode"] = str(self.sync_mode)
        elif include_empty:
            result["syncMode"] = Union[str, SyncModeEnum]()
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        app_id: str,
        env: Optional[Union[str, EnvEnum]] = None,
        publisher_authentication_key: Optional[str] = None,
        sync_mode: Optional[Union[str, SyncModeEnum]] = None,
        **kwargs,
    ) -> SteamIAPConfigRequest:
        instance = cls()
        instance.app_id = app_id
        if env is not None:
            instance.env = env
        if publisher_authentication_key is not None:
            instance.publisher_authentication_key = publisher_authentication_key
        if sync_mode is not None:
            instance.sync_mode = sync_mode
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> SteamIAPConfigRequest:
        instance = cls()
        if not dict_:
            return instance
        if "appId" in dict_ and dict_["appId"] is not None:
            instance.app_id = str(dict_["appId"])
        elif include_empty:
            instance.app_id = ""
        if "env" in dict_ and dict_["env"] is not None:
            instance.env = str(dict_["env"])
        elif include_empty:
            instance.env = Union[str, EnvEnum]()
        if (
            "publisherAuthenticationKey" in dict_
            and dict_["publisherAuthenticationKey"] is not None
        ):
            instance.publisher_authentication_key = str(
                dict_["publisherAuthenticationKey"]
            )
        elif include_empty:
            instance.publisher_authentication_key = ""
        if "syncMode" in dict_ and dict_["syncMode"] is not None:
            instance.sync_mode = str(dict_["syncMode"])
        elif include_empty:
            instance.sync_mode = Union[str, SyncModeEnum]()
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, SteamIAPConfigRequest]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[SteamIAPConfigRequest]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        SteamIAPConfigRequest,
        List[SteamIAPConfigRequest],
        Dict[Any, SteamIAPConfigRequest],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "appId": "app_id",
            "env": "env",
            "publisherAuthenticationKey": "publisher_authentication_key",
            "syncMode": "sync_mode",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "appId": True,
            "env": False,
            "publisherAuthenticationKey": False,
            "syncMode": False,
        }

    @staticmethod
    def get_enum_map() -> Dict[str, List[Any]]:
        return {
            "env": ["LIVE", "SANDBOX"],
            "syncMode": ["INVENTORY", "TRANSACTION"],
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import CreateLocalizedPolicyVersionRequest
from ..models import CreateLocalizedPolicyVersionResponse
from ..models import ErrorEntity
from ..models import RetrieveLocalizedPolicyVersionPublicResponse
from ..models import RetrieveLocalizedPolicyVersionResponse
from ..models import UpdateLocalizedPolicyVersionRequest
from ..models import UpdateLocalizedPolicyVersionResponse
from ..models import UploadLocalizedPolicyVersionAttachmentResponse
from ..models import UploadPolicyVersionAttachmentRequest

from ..operations.localized_policy_versions import OldCreateLocalizedPolicyVersion
from ..operations.localized_policy_versions import (
    OldPublicRetrieveSingleLocalizedPolicyVersion,
)
from ..operations.localized_policy_versions import OldRequestPresignedURL
from ..operations.localized_policy_versions import OldRetrieveLocalizedPolicyVersions
from ..operations.localized_policy_versions import (
    OldRetrieveSingleLocalizedPolicyVersion,
)
from ..operations.localized_policy_versions import OldSetDefaultLocalizedPolicy
from ..operations.localized_policy_versions import OldUpdateLocalizedPolicyVersion


@same_doc_as(OldCreateLocalizedPolicyVersion)
def old_create_localized_policy_version(
    policy_version_id: str,
    body: Optional[CreateLocalizedPolicyVersionRequest] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Create a Localized Version from Country-Specific Policy (oldCreateLocalizedPolicyVersion)

    Create a version of a particular country-specific policy.

    Properties:
        url: /agreement/admin/localized-policy-versions/versions/{policyVersionId}

        method: POST

        tags: ["Localized Policy Versions"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL CreateLocalizedPolicyVersionRequest in body

        policy_version_id: (policyVersionId) REQUIRED str in path

    Responses:
        201: Created - CreateLocalizedPolicyVersionResponse (successful operation)

        400: Bad Request - ErrorEntity (40033: errors.net.accelbyte.platform.legal.invalid_policy_version)

        409: Conflict - ErrorEntity (40044: errors.net.accelbyte.platform.legal.localized_policy_version_already_exist)
    """
    request = OldCreateLocalizedPolicyVersion.create(
        policy_version_id=policy_version_id,
        body=body,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(OldCreateLocalizedPolicyVersion)
async def old_create_localized_policy_version_async(
    policy_version_id: str,
    body: Optional[CreateLocalizedPolicyVersionRequest] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Create a Localized Version from Country-Specific Policy (oldCreateLocalizedPolicyVersion)

    Create a version of a particular country-specific policy.

    Properties:
        url: /agreement/admin/localized-policy-versions/versions/{policyVersionId}

        method: POST

        tags: ["Localized Policy Versions"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL CreateLocalizedPolicyVersionRequest in body

        policy_version_id: (policyVersionId) REQUIRED str in path

    Responses:
        201: Created - CreateLocalizedPolicyVersionResponse (successful operation)

        400: Bad Request - ErrorEntity (40033: errors.net.accelbyte.platform.legal.invalid_policy_version)

        409: Conflict - ErrorEntity (40044: errors.net.accelbyte.platform.legal.localized_policy_version_already_exist)
    """
    request = OldCreateLocalizedPolicyVersion.create(
        policy_version_id=policy_version_id,
        body=body,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(OldPublicRetrieveSingleLocalizedPolicyVersion)
def old_public_retrieve_single_localized_policy_version(
    localized_policy_version_id: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Retrieve a Localized Version (oldPublicRetrieveSingleLocalizedPolicyVersion)

    Retrieve specific localized policy version including the policy version and base policy version where the localized policy version located.
    Other detail info:

    Properties:
        url: /agreement/public/localized-policy-versions/{localizedPolicyVersionId}

        method: GET

        tags: ["Localized Policy Versions"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        localized_policy_version_id: (localizedPolicyVersionId) REQUIRED str in path

    Responses:
        200: OK - RetrieveLocalizedPolicyVersionPublicResponse (successful operation)

        403: Forbidden - ErrorEntity (40081: errors.net.accelbyte.platform.legal.policy_not_accessible)

        404: Not Found - ErrorEntity (40038: errors.net.accelbyte.platform.legal.localized_policy_version_not_found)
    """
    request = OldPublicRetrieveSingleLocalizedPolicyVersion.create(
        localized_policy_version_id=localized_policy_version_id,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(OldPublicRetrieveSingleLocalizedPolicyVersion)
async def old_public_retrieve_single_localized_policy_version_async(
    localized_policy_version_id: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Retrieve a Localized Version (oldPublicRetrieveSingleLocalizedPolicyVersion)

    Retrieve specific localized policy version including the policy version and base policy version where the localized policy version located.
    Other detail info:

    Properties:
        url: /agreement/public/localized-policy-versions/{localizedPolicyVersionId}

        method: GET

        tags: ["Localized Policy Versions"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        localized_policy_version_id: (localizedPolicyVersionId) REQUIRED str in path

    Responses:
        200: OK - RetrieveLocalizedPolicyVersionPublicResponse (successful operation)

        403: Forbidden - ErrorEntity (40081: errors.net.accelbyte.platform.legal.policy_not_accessible)

        404: Not Found - ErrorEntity (40038: errors.net.accelbyte.platform.legal.localized_policy_version_not_found)
    """
    request = OldPublicRetrieveSingleLocalizedPolicyVersion.create(
        localized_policy_version_id=localized_policy_version_id,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(OldRequestPresignedURL)
def old_request_presigned_url(
    localized_policy_version_id: str,
    body: Optional[UploadPolicyVersionAttachmentRequest] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Request Presigned URL for Upload Document (oldRequestPresignedURL)

    Request presigned URL for upload attachment for a particular localized version of base policy.

    Properties:
        url: /agreement/admin/localized-policy-versions/{localizedPolicyVersionId}/attachments

        method: POST

        tags: ["Localized Policy Versions"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL UploadPolicyVersionAttachmentRequest in body

        localized_policy_version_id: (localizedPolicyVersionId) REQUIRED str in path

    Responses:
        201: Created - UploadLocalizedPolicyVersionAttachmentResponse (successful operation)

        400: Bad Request - ErrorEntity (40034: errors.net.accelbyte.platform.legal.invalid_file_type | 40037: errors.net.accelbyte.platform.legal.invalid_localized_policy_version | 40042: errors.net.accelbyte.platform.legal.policy_version_freezed)
    """
    request = OldRequestPresignedURL.create(
        localized_policy_version_id=localized_policy_version_id,
        body=body,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(OldRequestPresignedURL)
async def old_request_presigned_url_async(
    localized_policy_version_id: str,
    body: Optional[UploadPolicyVersionAttachmentRequest] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Request Presigned URL for Upload Document (oldRequestPresignedURL)

    Request presigned URL for upload attachment for a particular localized version of base policy.

    Properties:
        url: /agreement/admin/localized-policy-versions/{localizedPolicyVersionId}/attachments

        method: POST

        tags: ["Localized Policy Versions"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL UploadPolicyVersionAttachmentRequest in body

        localized_policy_version_id: (localizedPolicyVersionId) REQUIRED str in path

    Responses:
        201: Created - UploadLocalizedPolicyVersionAttachmentResponse (successful operation)

        400: Bad Request - ErrorEntity (40034: errors.net.accelbyte.platform.legal.invalid_file_type | 40037: errors.net.accelbyte.platform.legal.invalid_localized_policy_version | 40042: errors.net.accelbyte.platform.legal.policy_version_freezed)
    """
    request = OldRequestPresignedURL.create(
        localized_policy_version_id=localized_policy_version_id,
        body=body,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(OldRetrieveLocalizedPolicyVersions)
def old_retrieve_localized_policy_versions(
    policy_version_id: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Retrieve Versions from Country-Specific Policy (oldRetrieveLocalizedPolicyVersions)

    Retrieve versions of a particular country-specific policy.

    Properties:
        url: /agreement/admin/localized-policy-versions/versions/{policyVersionId}

        method: GET

        tags: ["Localized Policy Versions"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        policy_version_id: (policyVersionId) REQUIRED str in path

    Responses:
        200: OK - List[RetrieveLocalizedPolicyVersionResponse] (successful operation)
    """
    request = OldRetrieveLocalizedPolicyVersions.create(
        policy_version_id=policy_version_id,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(OldRetrieveLocalizedPolicyVersions)
async def old_retrieve_localized_policy_versions_async(
    policy_version_id: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Retrieve Versions from Country-Specific Policy (oldRetrieveLocalizedPolicyVersions)

    Retrieve versions of a particular country-specific policy.

    Properties:
        url: /agreement/admin/localized-policy-versions/versions/{policyVersionId}

        method: GET

        tags: ["Localized Policy Versions"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        policy_version_id: (policyVersionId) REQUIRED str in path

    Responses:
        200: OK - List[RetrieveLocalizedPolicyVersionResponse] (successful operation)
    """
    request = OldRetrieveLocalizedPolicyVersions.create(
        policy_version_id=policy_version_id,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(OldRetrieveSingleLocalizedPolicyVersion)
def old_retrieve_single_localized_policy_version(
    localized_policy_version_id: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Retrieve a Localized Version from Country-Specific Policy (oldRetrieveSingleLocalizedPolicyVersion)

    Retrieve a version of a particular country-specific policy.

    Properties:
        url: /agreement/admin/localized-policy-versions/{localizedPolicyVersionId}

        method: GET

        tags: ["Localized Policy Versions"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        localized_policy_version_id: (localizedPolicyVersionId) REQUIRED str in path

    Responses:
        200: OK - RetrieveLocalizedPolicyVersionResponse (successful operation)

        404: Not Found - ErrorEntity (2912: errors.net.accelbyte.platform.legal.policy_version_not_found)
    """
    request = OldRetrieveSingleLocalizedPolicyVersion.create(
        localized_policy_version_id=localized_policy_version_id,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(OldRetrieveSingleLocalizedPolicyVersion)
async def old_retrieve_single_localized_policy_version_async(
    localized_policy_version_id: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Retrieve a Localized Version from Country-Specific Policy (oldRetrieveSingleLocalizedPolicyVersion)

    Retrieve a version of a particular country-specific policy.

    Properties:
        url: /agreement/admin/localized-policy-versions/{localizedPolicyVersionId}

        method: GET

        tags: ["Localized Policy Versions"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        localized_policy_version_id: (localizedPolicyVersionId) REQUIRED str in path

    Responses:
        200: OK - RetrieveLocalizedPolicyVersionResponse (successful operation)

        404: Not Found - ErrorEntity (2912: errors.net.accelbyte.platform.legal.policy_version_not_found)
    """
    request = OldRetrieveSingleLocalizedPolicyVersion.create(
        localized_policy_version_id=localized_policy_version_id,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(OldSetDefaultLocalizedPolicy)
def old_set_default_localized_policy(
    localized_policy_version_id: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Set Default Localized Policy (oldSetDefaultLocalizedPolicy)

    Update a localized version policy to be the default.

    Properties:
        url: /agreement/admin/localized-policy-versions/{localizedPolicyVersionId}/default

        method: PATCH

        tags: ["Localized Policy Versions"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        localized_policy_version_id: (localizedPolicyVersionId) REQUIRED str in path

    Responses:
        200: OK - (Successful operation)

        400: Bad Request - ErrorEntity (40035: errors.net.accelbyte.platform.legal.invalid_localize_policy_version)
    """
    request = OldSetDefaultLocalizedPolicy.create(
        localized_policy_version_id=localized_policy_version_id,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(OldSetDefaultLocalizedPolicy)
async def old_set_default_localized_policy_async(
    localized_policy_version_id: str,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Set Default Localized Policy (oldSetDefaultLocalizedPolicy)

    Update a localized version policy to be the default.

    Properties:
        url: /agreement/admin/localized-policy-versions/{localizedPolicyVersionId}/default

        method: PATCH

        tags: ["Localized Policy Versions"]

        consumes: []

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        localized_policy_version_id: (localizedPolicyVersionId) REQUIRED str in path

    Responses:
        200: OK - (Successful operation)

        400: Bad Request - ErrorEntity (40035: errors.net.accelbyte.platform.legal.invalid_localize_policy_version)
    """
    request = OldSetDefaultLocalizedPolicy.create(
        localized_policy_version_id=localized_policy_version_id,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(OldUpdateLocalizedPolicyVersion)
def old_update_localized_policy_version(
    localized_policy_version_id: str,
    body: Optional[UpdateLocalizedPolicyVersionRequest] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update a Localized Version from Country-Specific Policy (oldUpdateLocalizedPolicyVersion)

    Update a version of a particular country-specific policy.

    Properties:
        url: /agreement/admin/localized-policy-versions/{localizedPolicyVersionId}

        method: PUT

        tags: ["Localized Policy Versions"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL UpdateLocalizedPolicyVersionRequest in body

        localized_policy_version_id: (localizedPolicyVersionId) REQUIRED str in path

    Responses:
        200: OK - UpdateLocalizedPolicyVersionResponse (successful operation)

        400: Bad Request - ErrorEntity (40035: errors.net.accelbyte.platform.legal.invalid_policy_version)
    """
    request = OldUpdateLocalizedPolicyVersion.create(
        localized_policy_version_id=localized_policy_version_id,
        body=body,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(OldUpdateLocalizedPolicyVersion)
async def old_update_localized_policy_version_async(
    localized_policy_version_id: str,
    body: Optional[UpdateLocalizedPolicyVersionRequest] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update a Localized Version from Country-Specific Policy (oldUpdateLocalizedPolicyVersion)

    Update a version of a particular country-specific policy.

    Properties:
        url: /agreement/admin/localized-policy-versions/{localizedPolicyVersionId}

        method: PUT

        tags: ["Localized Policy Versions"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) OPTIONAL UpdateLocalizedPolicyVersionRequest in body

        localized_policy_version_id: (localizedPolicyVersionId) REQUIRED str in path

    Responses:
        200: OK - UpdateLocalizedPolicyVersionResponse (successful operation)

        400: Bad Request - ErrorEntity (40035: errors.net.accelbyte.platform.legal.invalid_policy_version)
    """
    request = OldUpdateLocalizedPolicyVersion.create(
        localized_policy_version_id=localized_policy_version_id,
        body=body,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )
